{% extends "registration/base.html" %}{% load i18n %}
{% block registration_content %}

<div class="row"><div class="col-md-9">
    <h2>{% trans "Password modification" %}</h2>
    {% if form.errors %}
        <h3 class="warning">{% trans "Error" %}</h3>
    {% else %}
        <p />
    {% endif %}

    <form action="{% url 'password_change' %}" method="post">
        {% csrf_token %}

        {% if form.non_field_errors %}
        {{form.non_field_errors}}
        {% endif %}

        {% for field in form %}
          {% include "balafon/_field_form.html" with allow_required_sign=1 %}
        {% endfor %}

        <div class="row"><div class="col-sm-12">
          <div class="help-block required">{% trans "* : Required fields" %}</div>
        </div></div>

        <div class="row"><div class="col-sm-3 col-sm-offset-9" style="margin-top: 20px;">
          <input class="btn btn-primary pull-right" type="submit" value="{% trans 'Change password' %}" />
        </div></div>

    </form>
</div></div>
{% endblock %}


