# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-04-09 13:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Profile', '0004_auto_20160601_1128'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contactprofile',
            name='entity_name',
            field=models.CharField(blank=True, default='', max_length=200, verbose_name='Entity name'),
        ),
        migrations.AlterField(
            model_name='contactprofile',
            name='gender',
            field=models.IntegerField(blank=True, choices=[(0, ''), (1, 'Mr'), (2, 'Mrs')], default=0, verbose_name='Gender'),
        ),
        migrations.AlterField(
            model_name='contactprofile',
            name='groups_ids',
            field=models.CharField(blank=True, default='', max_length=100),
        ),
        migrations.AlterField(
            model_name='contactprofile',
            name='subscriptions_ids',
            field=models.CharField(blank=True, default='', max_length=100),
        ),
    ]
