{% extends "balafon/_bs_section.html" %}
{% load i18n balafon_utils favorite_tags %}

{% block section_title %}
  <div class="row">
  <div class="col-md-12">
    <div class="opportunity-title">
      <span class="glyphicon glyphicon-tag"></span> <h2 class="inline-block">{{opportunity.name}}</h2>
    </div>
  </div>
</div>
{% endblock %}

{% block section_data %}
<div class="row">
  <div class="col-md-12">
    <div class="">
      <span class="contenteditable description inline-block" rel="{% url "auto_save_data" "opportunity" "detail" opportunity.id %}" contenteditable="true">
        {{opportunity.detail|linebreaksbr}}
      </span>
    </div>
  </div>
</div>
{% endblock %}


{% block section_buttons %}
  <li><a class="colorbox-form" href="{% url "crm_edit_opportunity" opportunity.id %}">{% trans "Edit" %}</a></li>
  <li><a class="colorbox-form" href="{% url "crm_delete_opportunity" opportunity.id %}">{% trans "Delete" %}</a></li>
{% endblock %}

{% block section_favorite %}
{% favorite_item object=opportunity %}
{% endblock %}