{% load i18n %}
<td{% if colspan %} colspan={{colspan}}{% endif %}>
  {% if field.errors %}
  <ul class="fielderror errorlist">
      {% for err in field.errors %}
          <li>{{err}}</li>
      {% endfor %}
  </ul>
  {% endif %}
  {{field}}{% if field.help_text %}<div class="help-text">{{ field.help_text }}</div>{% endif %}
</td>
