{% extends "admin/change_list.html" %}{% load i18n %}
{% block object-tools-items %}

    {{ block.super }}
    <li>
        <a href="{% url 'store_xls_catalogue' 0 %}" class="grp-state-focus">
          {% trans "Catalogue" %}
        </a>
    </li>
    <li>
        <a href="{% url 'store_xls_articles' 0 0%}" class="grp-state-focus">
          {% trans "Articles" %}
        </a>
    </li>
    <li>
        <a href="{% url 'store_store_item_admin_export' %}" class="grp-state-focus">
          {% trans "Export Stock" %}
        </a>
    </li>
    <li>
        <a href="{% url 'store_store_item_admin_export_alert' %}" class="grp-state-focus">
          {% trans "Export missing Stock" %}
        </a>
    </li>
    <li>
        <a href="{% url 'store_import_stock' %}" class="grp-state-focus">{% trans "Import stock" %}</a>
    </li>

{% endblock %}