{% extends "Emailing/public/base_custom.html" %}
{% load i18n %}

{% block title %}{% trans "Subscribe" %}{% endblock %}

{% block custom_content %}
  {{ block.super }}
    
  <form method="post" action="">{% csrf_token %}
    {{form.as_p}}
    <input type="submit" value="{% trans "Ok" %}">
  </form>
{% endblock %}