{% extends "registration/base.html" %}{% load i18n %}
{% block registration_content %}
<h2>{% trans "Registration complete" %}</h2>
{% blocktrans %}
We sent you an email. It will help you to activate your account.
{% endblocktrans %}
{% endblock %}