# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-07-06 09:56
from __future__ import unicode_literals

from decimal import Decimal
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Store', '0013_auto_20180409_1301'),
    ]

    operations = [
        migrations.AddField(
            model_name='saleitem',
            name='percentage',
            field=models.DecimalField(decimal_places=2, default=Decimal('100'), help_text='Only a percentage of the item price', max_digits=5, verbose_name='percentage'),
        ),
    ]
