{% load i18n static coop_navigation coop_bar_tags %}<!DOCYTPE HTML><html lang="{{ LANGUAGE_CODE }}">
<head>
    <meta charset="utf-8"/>
	<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
	<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
    <title>{% block meta_title %}{% endblock %}{% if settings.SITE_TITLE %} | {{ settings.SITE_TITLE }}{% endif %}</title>
    {% block jquery_declaration %}
    <script type="text/javascript" charset="utf-8" src="{{ STATIC_URL }}js/jquery-1.11.3.min.js"></script>
    {% endblock %}
    <link rel="stylesheet" href="{{ STATIC_URL }}css/coop_cms.css" type="text/css" />
    {% coop_bar_headers %}
    {% block extra_head %}{% endblock %}
</head>
<body>
<div id="container">
<div id="main">
  {% include "coop_cms/_messages.html" %}
  {% block navigation %}
  <ul id="nav">
    {% navigation_as_nested_ul li_template="coop_cms/dropdown_li.html" ul_template="coop_cms/dropdown_ul.html" li_args="coop_cms/dropdown_li_class.html" %}
  </ul>
  {% endblock %}
  <div class="document">
      {% block document %}
      {% endblock %}
  </div>
</div>
</div>
{% coop_bar %}
</body>
</html>
