{% extends "Emailing/public/base_custom.html" %}
{% load i18n %}
{% block custom_content %}
      <h1>{% blocktrans %}
      You have subscribed to our mailing-list.
      {% endblocktrans %}</h1>
      <p>
      {% blocktrans %}
      An error occured while sending you an address verification email.<br /><br />
      We are sorry about this situation. We will contact you shortly in order to fix the issue.
      {% endblocktrans %}
      </p>
{% endblock %}
