{% extends "admin/change_form.html" %}{% load i18n %}
{% block object-tools-items %}

    {{ block.super }}
    <li>
        <a href="{% url 'store_xls_articles' 0 original.pk %}" class="grp-state-focus">
          {% trans "Articles" %}
        </a>
    </li>

{% endblock %}