# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-07-09 13:03
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('Crm', '0023_action_frozen'),
    ]

    operations = [
        migrations.AddField(
            model_name='actionstatus',
            name='next_on_send',
            field=models.ForeignKey(blank=True, default=None, help_text='automatically change the status when sent by email', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='Crm.ActionStatus', verbose_name='Next status on send by email'),
        ),
    ]
