{% extends "registration/base.html" %}{% load i18n %}
{% block registration_content %}
<h2>{% trans "An Email has been sent" %}</h2>
<p>
    {% trans "It contains the procedure to reset the password." %}
</p>
{% endblock %}
    
