# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-04-09 13:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Store', '0012_auto_20180104_1728'),
    ]

    operations = [
        migrations.AlterField(
            model_name='certificate',
            name='logo',
            field=models.ImageField(blank=True, default='', upload_to='certificates'),
        ),
        migrations.AlterField(
            model_name='discount',
            name='short_name',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='short name'),
        ),
        migrations.AlterField(
            model_name='priceclass',
            name='description',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='pricepolicy',
            name='parameters',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='parameters'),
        ),
        migrations.AlterField(
            model_name='pricepolicy',
            name='policy',
            field=models.CharField(choices=[('from_category', 'Inherit from category'), ('multiply_purchase_by_ratio', 'Multiply purchase price by ratio')], max_length=100, verbose_name='policy'),
        ),
        migrations.AlterField(
            model_name='saleitem',
            name='text',
            field=models.TextField(blank=True, default='', max_length=3000, verbose_name='Text'),
        ),
        migrations.AlterField(
            model_name='storeitem',
            name='description',
            field=models.TextField(blank=True, default='', verbose_name='description'),
        ),
        migrations.AlterField(
            model_name='storeitem',
            name='image',
            field=models.ImageField(blank=True, default=None, null=True, upload_to='storeitems', verbose_name='image'),
        ),
        migrations.AlterField(
            model_name='storeitem',
            name='origin',
            field=models.CharField(blank=True, default='', max_length=50, verbose_name='Origine'),
        ),
        migrations.AlterField(
            model_name='storeitem',
            name='reference',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='reference'),
        ),
        migrations.AlterField(
            model_name='storeitemcategory',
            name='default_image',
            field=models.ImageField(blank=True, default=None, null=True, upload_to='storeitemcats', verbose_name='image'),
        ),
        migrations.AlterField(
            model_name='storeitemcategory',
            name='icon',
            field=models.CharField(blank=True, default='', max_length=20),
        ),
        migrations.AlterField(
            model_name='storeitemimport',
            name='data',
            field=models.FileField(help_text='An Excel file (*.xls) with the data', upload_to='store_item_imports', verbose_name='Import file'),
        ),
        migrations.AlterField(
            model_name='storeitemimport',
            name='default_brand',
            field=models.CharField(blank=True, default='', help_text='If defined, it will be used if no brand is given', max_length=50, verbose_name='default Brand'),
        ),
        migrations.AlterField(
            model_name='storeitemimport',
            name='error_message',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='error message'),
        ),
        migrations.AlterField(
            model_name='storeitemimport',
            name='fields',
            field=models.CharField(default='name,brand,reference,category,purchase_price,vat_rate', help_text="Fields to import in order: if the attribute doesn't exist, create a custom property", max_length=300, verbose_name='fields'),
        ),
        migrations.AlterField(
            model_name='storeitemimport',
            name='import_error',
            field=models.TextField(blank=True, default='', verbose_name='import error'),
        ),
        migrations.AlterField(
            model_name='storeitemproperty',
            name='label',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='label'),
        ),
        migrations.AlterField(
            model_name='storeitempropertyvalue',
            name='value',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='value'),
        ),
        migrations.AlterField(
            model_name='storeitemtag',
            name='icon',
            field=models.CharField(blank=True, default='', max_length=20),
        ),
        migrations.AlterField(
            model_name='storemanagementactiontype',
            name='references_text',
            field=models.TextField(blank=True, default='', help_text='this text will be added at the bottom of the commercial document', verbose_name='references text'),
        ),
        migrations.AlterField(
            model_name='storemanagementactiontype',
            name='template_name',
            field=models.CharField(blank=True, default='', help_text='Set the name of a custom template for commercial document', max_length=100, verbose_name='template name'),
        ),
    ]
