html,
body {
  height: 100%;
  /* The html and body elements cannot have any padding or margin. */
}
.version {
  font-size: 0.6em;
}
/*
.navbar-default{
  background-color: @navbar_color;
  border-color: @navbar_border_color;
}*/
.row.section {
  border: solid thin #eee;
  padding: 2px;
  margin-bottom: 5px;
}
.row.section .section-content {
  background: #eee;
  padding: 1px;
  min-height: 100px;
}
.row.section .section-content .section-data {
  padding-top: 10px;
}
.table.micro-table {
  font-size: 0.6em;
}
.row.section .section-data .table.table-striped > tbody > tr:nth-child(odd) > td,
.row.section .section-data .table.table-striped > tbody > tr:nth-child(odd) > th {
  background-color: #fff;
}
.row.section .section-data .table.table-striped > tbody > tr:nth-child(even) > td,
.row.section .section-data .table.table-striped > tbody > tr:nth-child(even) > th {
  background-color: #f8f8f8;
}
.row.section .section-data .table.table-bordered > tbody > tr > th {
  color: #888;
}
.row.section .section-data .table.table-bordered > tbody > tr:nth-child(odd) > td {
  background-color: #fff;
}
.row.section .section-data .table.table-bordered > tbody > tr:nth-child(even) > td {
  background-color: #f8f8f8;
}
.note {
  background: #fffa94;
  padding: 2px;
}
.table-row {
  display: table-row;
}
.table-cell {
  display: table-row;
}
.btn.group-tag {
  margin-bottom: 2px;
}
.group-tag a {
  color: #fff;
}
.custom-field {
  margin-right: 10px;
  margin-bottom: 8px;
  display: inline-block;
}
.custom-field .custom-field-label {
  border: solid thin #ccc;
  border-right: none;
  border-radius: 4px 0 0 4px;
  background-color: #000;
  color: #fff;
  padding: 4px;
  font-size: 12px;
}
.custom-field .custom-field-value {
  border: solid thin #ccc;
  border-radius: 0 4px 4px 0;
  padding: 4px;
  font-size: 12px;
  background-color: #fff;
  color: #000;
  border-left: none;
  margin-left: -4px;
}
/*
.actions .row [class*="col-"]{
    margin-bottom: -99999px;
    padding-bottom: 99999px;
}
*/
.actions .row {
  /*overflow: hidden;*/
  padding: 1px 0;
}
.actions .label {
  font-size: 0.9em;
}
.actions .label-text {
  color: #888;
}
.actions .label.label-default {
  background: #ddd;
  color: #000;
}
.actions .label.label-default a {
  color: #000;
}
.label-in-charge {
  background: #888;
  margin-right: 2px;
}
.label-date {
  color: #000;
  margin-right: 2px;
}
.label-member {
  color: #000;
  background: #eee;
  border: solid thin #ccc;
  margin-bottom: 3px;
  display: inline-block;
}
.label-member.label-new-member {
  background: #ffcc66;
}
.label-member.label-removed {
  background: #882222;
  color: #fff;
}
.label-group {
  color: #000;
  background: #eee;
  border: solid thin #ccc;
  margin-bottom: 3px;
  display: inline-block;
}
.label-member.label-removed a {
  color: #eee;
}
.actions .action .label-in-charge {
  margin-top: 4px;
}
.label-in-charge.me-in-charge {
  background: #4a4;
}
.label-bigger {
  font-size: 1em;
}
.label-bigger .glyphicon-tower,
.label-bigger .glyphicon-user {
  margin-right: 5px;
}
.label-bigger .glyphicon {
  font-size: 0.7em;
}
/*
.actions .row.action .col-action {
    border: solid thin #eee;
    background: #fff;
}

.actions .row.action .col-action.col1 {
    font-size: 0.8em;
    text-align: center;
}

.gutterless [class*="col-"] {
    padding-left:0;
    padding-right: 0;
    margin: 0;
 }
.gutterless [class*="col-"] {
    padding-left:0;
    padding-right: 0;
    margin: 0;
    border: solid thin #eee;
    background: #fff;
}*/
.label-date.label-danger {
  background: #fc8c84;
}
.label-date.label-warning {
  background: #ffcc77;
}
.label-not-yet {
  background: #ddd;
}
.action-subject {
  display: inline-block;
  border: solid thin #f0f0fc;
  vertical-align: top;
  padding: 1px 4px;
  background: #fffa94;
  color: #000;
}
.label-action-contact {
  background: #ccc;
}
.action-contacts {
  margin-top: 5px;
  display: inline-block;
}
.row.section .section-data .table.table-bordered > tbody > tr > td,
.row.section .section-data .table.table-bordered > tbody > tr > th {
  font-size: 14px;
}
.action-details {
  display: inline-block;
}
.actions .action {
  background: #fff;
  padding: 5px;
  border: solid thin #ccc;
  margin-bottom: 2px;
}
.actions .action.even {
  background: #f8f8f8;
}
.actions .action.done {
  background: #ccc;
}
.actions .action.done.even {
  background: #c0c0c0;
}
.actions .action .show-note {
  color: #888;
}
.actions .action .show-note.has-note {
  color: #000;
}
.prio-1,
.prio-1 a {
  color: #888;
}
.prio-2,
.prio-2 a {
  color: #000;
}
.prio-1,
.prio-1 a {
  color: red;
}
.section-header {
  padding: 5px;
  background: #444;
  color: #fff;
  font-weight: bold;
  font-size: 1.1em;
}
.main-section-header {
  background: #444;
}
.section-header img {
  background: #fff;
}
.main-section-header .section-title {
  font-size: 1.1em;
}
.main-section-header .section-subtitle {
  font-size: 0.6em;
}
.section-action-set-title {
  font-size: 1.1em;
  margin-top: 20px;
  padding: 5px;
  background: #444;
  color: #fff;
  font-weight: bold;
}
.badge.highlight {
  background: #fd4;
  color: #000;
}
.contact-entity-info,
.contact-entity-info:hover {
  color: #ddd;
}
.logo-container {
  display: inline-block;
  background: #fff;
  height: 64px;
  width: 64px;
}
.data-groups {
  padding: 5px 0;
}
.btn-gray {
  background: #888;
}
.btn-gray .disabled {
  color: #888;
}
li.quick-search-form {
  margin-top: 15px;
}
/* Large desktop */
/* Portrait tablet to landscape and desktop */
/* Landscape phone to portrait tablet */
@media (max-width: 767px) {
  li.quick-search-form {
    margin-top: 0;
    margin-left: 15px;
  }
}
/* Landscape phones and down */
.navbar img {
  background: #fff;
}
.action-note {
  background: #fffa94;
  padding: 2px;
}
.dropdown-menu > li > a.disabled {
  color: #ccc;
}
.import-contact-intro {
  padding: 10px;
  font-size: 0.9em;
  border: solid thin #444;
  background: #eee;
  margin-bottom: 10px;
}
.confirm-import-intro {
  padding: 10px;
  font-size: 0.9em;
  border: solid thin #444;
  background: #eee;
  margin: 10px 0;
}
.font-small {
  font-size: 0.8em;
}
.search-block {
  font-size: 0.9em;
  padding: 10px;
  background: #eee;
  border: 2px groove #888;
  margin-bottom: 10px;
}
.half-width {
  width: 50%;
  display: inline-block;
}
.chosen-container .chosen-drop .chosen-results li.group-result {
  cursor: default;
  display: list-item;
  font-weight: bold;
  color: #888;
  margin-left: -15px;
}
.search-btn {
  margin-top: 10px;
  margin-right: 5px;
}
.search-form .fields {
  margin-top: 10px;
}
.field-error {
  margin-top: -35px;
  margin-right: 20px;
  float: right;
}
a.link-warning {
  color: #ed9f35;
}
table.contact-table {
  margin: 0;
}
.contact-table thead > tr > th,
.contact-table tbody > tr > th,
.contact-table tfoot > tr > th,
.contact-table thead > tr > td,
.contact-table tbody > tr > td,
.contact-table tfoot > tr > td {
  border: none;
}
.row.section .section-data .contact-table.table-striped > tbody > tr > td,
.row.section .section-data .contact-table.table-striped > tbody > tr > th {
  background-color: #fff;
  padding: 2px 0;
}
.contact-table tr.excluded {
  text-decoration: line-through;
}
.row.section .section-data .table.table-striped > tbody > tr.excluded > td,
.row.section .section-data .table.table-striped > tbody > tr.excluded > th {
  background-color: #999;
  color: #fff;
}
.row.section .section-data .table.table-striped > tbody > tr.excluded > td a,
.row.section .section-data .table.table-striped > tbody > tr.excluded > th a {
  color: #fff;
}
.contact-table tr .exclude-btn {
  display: inline-block;
}
.contact-table tr .include-btn {
  display: none;
}
.contact-table tr.excluded .exclude-btn {
  display: none;
}
.contact-table tr.excluded .include-btn {
  display: inline-block;
}
.selector h2 {
  font-size: 14px;
  margin: 0;
  padding: 4px 0;
}
.selector select,
.selector .selector-filter {
  margin: 0;
  border: solid thin #ccc !important;
  margin-top: -10px;
}
.description.contenteditable {
  background: #fffa94;
}
.contenteditable {
  min-height: 14px;
  padding: 2px;
  min-width: 5px;
  background: #fffa94;
}
.inline-block {
  display: inline-block;
}
.tabbar {
  border-bottom: solid 1px #ccc;
  padding-right: 20px;
}
.tabbar .tab {
  padding: 5px 10px;
  border: solid 1px #aaa;
  border-bottom: none;
  background: #eee;
  cursor: pointer;
  border-radius: 5px 5px 0 0;
  display: inline-block;
  min-width: 50px;
}
.tabbar .tab.selected {
  background: #ccc;
}
.tabbar .tab.error {
  background: #e20;
}
.tabbar .tab.error.selected {
  background: #d00;
}
.fieldsets .row {
  margin-bottom: 15px;
}
ul.chosen-choices .search-field input {
  height: 25px !important;
  width: 300px !important;
}
.action-overflow-warning {
  color: #000;
  background: #888;
  padding: 2px 10px;
}
.action-overflow-warning.no-set-title {
  margin-top: -10px;
}
.label-primary a,
.label-default a {
  color: #fff;
}
.label-primary a:hover,
.label-default a:hover {
  color: #eee;
}
.action-archive-filter {
  margin-bottom: 10px;
}
.action-archive-filter h2 {
  vertical-align: top;
  font-size: 24px;
  margin: 0;
  padding: 0;
}
.action-archive-filter select.form-control + .chosen-container-multi .chosen-choices li.search-choice {
  font-size: 12px;
}
.action-archive-filter select {
  vertical-align: top;
}
.action-archive-filter .btn {
  height: 32px;
}
.groups-header .btn-xs,
.custom-field-list .btn-xs {
  height: 19px;
}
.tabbar-form fieldset {
  padding-top: 20px;
}
.action-dt-label {
  font-size: 12px;
  padding: 2px 4px;
  background: #888;
  color: #fff;
  border: solid 1px #000;
  border-radius: 2px 0 0 2px;
}
.action-dt-value {
  font-size: 12px;
  padding: 2px 4px;
  background: #eee;
  color: #000;
  border: solid 1px #000;
  border-radius: 0 2px 2px 0;
  margin-left: -5px;
  border-left: none;
}
.done-action-flag {
  display: inline-block;
  position: relative;
}
.done-action-flag .done-date {
  display: none;
  position: absolute;
  top: 16px;
  left: -80px;
  background: #428BCA;
  color: #fff;
  padding: 2px;
  width: 96px;
  z-index: 100;
  font-size: 10px;
  border-radius: 2px;
}
.done-action-flag:hover .done-date {
  display: inline;
}
.action-opprtunity {
  margin-right: 2px;
}
.opportunity-title h2 {
  margin: 0;
  padding: 0;
  font-size: 24px;
}
.cursor-pointer {
  cursor: pointer;
}
.btn-yellow {
  background: #ffb;
}
.btn-yellow:hover {
  background: #ffa;
}
.custom-field-list {
  border: solid #bbb thin;
  border-radius: 8px;
  padding: 2px;
  margin-top: 5px;
  padding-bottom: 5px;
}
.groups-box {
  border: solid #bbb thin;
  border-radius: 8px;
  padding: 2px;
}
.groups-box .groups-header,
.custom-field-list .custom-field-list-header {
  background: #bbb;
  font-size: 13px;
  font-weight: 500;
  padding: 3px;
  border-radius: 2px;
}
.groups-box .groups-header .btn,
.custom-field-list .custom-field-list-header .btn {
  background: #bbb;
  border: solid thin #fff;
  color: #000;
  padding: 1px 5px !important;
}
.groups-box .groups-header .btn:hover,
.custom-field-list .custom-field-list-header .btn:hover {
  background: #aaa;
}
.section-favorite .glyphicon {
  margin-bottom: 5px;
}
a.header-link {
  color: #fff;
  text-decoration: none;
}
a.header-link:hover {
  color: #ccc;
}
ul.errorlist,
ul.fielderror {
  list-style: none;
  margin: 0;
  padding: 0;
}
ul.errorlist li {
  padding: 5px;
  margin: 5px 0;
  border: solid #ccc 1px;
  background: #eee;
  color: #c00;
}
ul.fielderror li {
  font-size: 0.8em;
  color: #c00;
}
table.with-odd-even tr.odd td {
  background: #f8f8f8;
}
table.with-odd-even tr.even td {
  background: #fff;
}
.contacts-table th {
  background: #eee;
}
.contacts-table th.extra-data,
.contacts-table td.extra-data {
  font-size: 0.8em;
}
.make-homepage {
  color: #fff;
  margin-top: 25px;
  margin-right: 10px;
  cursor: pointer;
}
.make-homepage.success {
  color: #6b6;
}
.make-homepage.error {
  color: #c33;
}
.make-homepage.disabled {
  color: #888;
}
.statistics .row {
  margin: 0;
  padding: 0;
  border: solid thin #ccc;
  margin-bottom: 2px;
}
.statistics .row > div > div {
  padding: 5px 10px;
}
.statistics .row:nth-child(odd) {
  background-color: #f8f8f8;
}
ul.coop-cms_user-messages {
  top: 60px;
  z-index: 9999;
}
.nav .tooltip .tooltip-inner {
  background-color: #444;
}
.nav .tooltip .tooltip-arrow {
  border-bottom-color: #444;
}
.dropdown-menu {
  height: auto !important;
  overflow: visible !important;
}
.btn-action-status {
  background: #ddd;
  font-weight: bold;
}
.label-action-who a {
  display: inline-block;
  overflow: hidden;
  vertical-align: middle;
}
.letter-bar {
  background: #eee;
  padding: 2px 10px;
}
.container.container-not-preview {
  padding-top: 70px;
}
@media (min-width: 768px) and (max-width: 991px) {
  .container.container-not-preview {
    padding-top: 140px;
  }
}
