{% extends "forms/autocomplete_input.html" %}
{% block get_value_url %}{% url "crm_get_city_name" value %}{% endblock %}
{% block get_list_url %}{% url "crm_get_cities" %}{% endblock %}
{% block extra_filter_value %}
country_id = $('select[name=country]').val();
{% endblock %}
{% block extra_filter %}+"&country="+country_id{% endblock %}
{% block get_id_url %}{% url "crm_get_city_id" %}{% endblock %}