<!DOCYTPE html>
<html>
<head>
	{% load i18n static coop_navigation coop_utils coop_bar_tags thumbnail %}
	<meta charset="utf-8"/>
	<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
	<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
		
	<title>{% block extra_title %}{% endblock %}</title>
	<meta name="description" content="{% block description %}{% endblock %}">
	
    {% block jquery_declaration %}
	{% include "coop_cms/_js_includes.html" %}
	{% endblock %}
	
	<link rel="stylesheet" href="{{ STATIC_URL }}css/coop_cms.css?v=1.0" type="text/css" />
    {% coop_bar_headers %}
	<style>
		select[name=language] {
			display: none;
		}
	</style>
	<script>
		$(function() {
			
	    	$("select[name=language]").hide();
			$(".lang-selector a").click(function() {
				$("select[name=language]").val($(this).attr('href'));
				$(".lang-selector form").submit();
				return false;
			})
			
			$("ul.nav a").each(function(idx, elt) {
				if ($(elt).attr('href') == window.location.pathname) {
					$(elt).addClass('selected');
				}
			})
		})
	</script>
	{% block extra_head %}{% endblock %}
</head>
<body>
	{% include "coop_cms/_messages.html" %}
	<div class="frame">
		{% block header %}
		<div class="header">
			<div class="logo">
				{% block logo %}{% endblock %}
			</div>
			<ul class="nav">
			{% block navigation %}
				{% navigation_as_nested_ul %}
			{% endblock %}
			</ul>
			<div class="lang-selector">
				{% include "coop_cms/_change_language.html" %}
				{% for l, n in LANGUAGES %}
					<a href="{{l}}"{% if l == LANGUAGE_CODE %} class="current"{% endif %}>{{l|upper}}</a>
					{% if not forloop.last %}&nbsp;|&nbsp;{% endif %}
				{% endfor %}
			</div>
		</div>
		{% endblock %}
		
		<div class="document">
			{% block document_wrapper %}
			<div class="document-text">
			{% block document %}{% endblock %}
			</div>
			{% endblock %}
			<div class="doc-footer"></div>
		</div>
		<div class="footer">
			{% include "coop_cms/_social_share.html" %}
			<div class="links">
			</div>
		</div>
		{% coop_bar %}
	</div>
</body>
</html>