{% extends "balafon/bs_base.html" %}{% load i18n %}

{% block header_bar %}
{% endblock %}
  
  
{% block main %}
<div class="login-header">
    <img src="{{STATIC_URL}}img/logo-balafon.png">
</div>
{% block registration_content %}
{% endblock %}
{% endblock %}
